#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2018-05-29
#
# Check Point Firewall connections metrics plugins
# checkpoint_fragments
#
# 2023-ß5-29: moved file to ~/local/lib/check_mk/gui/plugins/metrics
#
from cmk.gui.i18n import _

from cmk.gui.plugins.metrics.utils import (
    metric_info,
    graph_info,
    perfometer_info
)

metric_info['checkpoint_fragments_fwfrag_fragments'] = {
    'title': _('Fragments'),
    'unit': '1/s',
    'color': '11/a',
}
metric_info['checkpoint_fragments_fwfrag_expired'] = {
    'title': _('Fragments expired'),
    'unit': '1/s',
    'color': '21/a',
}
metric_info['checkpoint_fragments_fwfrag_packets'] = {
    'title': _('Fragmented packets'),
    'unit': '1/s',
    'color': '31/a',
}

graph_info['checkpoint_fragments'] = {
    'title': _('Check Point Firewall Fragments'),
    'metrics': [
        ('checkpoint_fragments_fwfrag_expired', 'line'),
        ('checkpoint_fragments_fwfrag_packets', 'line'),
        ('checkpoint_fragments_fwfrag_fragments', 'line'),
    ],
    'scalars': [
        ('checkpoint_fragments_fwfrag_fragments:crit', _('crit')),
        ('checkpoint_fragments_fwfrag_fragments:warn', _('warn')),
    ],
}

perfometer_info.append(('stacked', [
    {
        'type': 'logarithmic',
        'metric': 'checkpoint_fragments_fwfrag_fragments',
        'half_value': 500.0,
        'exponent': 2,
    },
    {
        'type': 'logarithmic',
        'metric': 'checkpoint_fragments_fwfrag_packets',
        'half_value': 100.0,
        'exponent': 2,
    },
]))
