#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2020-06-07
#
#
# 2022-11-30: fixed CheckParameterRulespecWithoutItem (from CheckParameterRulespecWithItem)
# 2023-ß5-29: moved file to ~/local/lib/check_mk/gui/plugins/wato

from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Dictionary,
    Integer,
    Tuple,
)

from cmk.gui.plugins.wato.utils import (
    CheckParameterRulespecWithoutItem,
    rulespec_registry,
    RulespecGroupCheckParametersNetworking,
)


def _parameter_valuespec_checkpoint_fragments():
    return Dictionary(
        elements=[
            ('warncritpackets',
             Tuple(
                 title=_('Levels for number of fragmented packets/s'),
                 elements=[
                     Integer(title=_('Warning at'), default_value=10, unit=_('Count')),
                     Integer(title=_('Critical at'), default_value=20, unit=_('Count')),
                 ])),
            ('warncritfragments',
             Tuple(
                 title=_('Levels for number of fragments/s'),
                 elements=[
                     Integer(title=_('Warning at'), default_value=10, unit=_('Count')),
                     Integer(title=_('Critical at'), default_value=20, unit=_('Count')),
                 ])),
            ('warncritexpired',
             Tuple(
                 title=_('Levels for number of expired fragments/s'),
                 elements=[
                     Integer(title=_('Warning at'), default_value=10, unit=_('Count')),
                     Integer(title=_('Critical at'), default_value=20, unit=_('Count')),
                 ])),
        ],
    )


rulespec_registry.register(
    CheckParameterRulespecWithoutItem(
        check_group_name='checkpoint_fragments',
        group=RulespecGroupCheckParametersNetworking,
        match_type='dict',
        parameter_valuespec=_parameter_valuespec_checkpoint_fragments,
        title=lambda: _('Check Point Fragments'),
    ))
